/*
Shallot is a Qt based file manager.
Copyright (C) 2014-2017 Josef Hahn

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "base/filesystemmodel.h"
#include "filesystemmodeldirectorytreeproxy.h"


sh::base::FilesystemModelDirectoryTreeProxy::FilesystemModelDirectoryTreeProxy(QObject *parent) :
    QSortFilterProxyModel(parent)
{
    this->sort(0, Qt::AscendingOrder);
}

bool sh::base::FilesystemModelDirectoryTreeProxy::filterAcceptsRow (int row, const QModelIndex & parent) const
{
    if (!parent.isValid()) return true;
    std::shared_ptr<sh::base::FilesystemNode> node = sh::base::FilesystemModel::instance()->getNodeForIndex(parent);
    if (row < node->childnodeCount())
    {
        std::shared_ptr<FilesystemNode> childnode = node->childnode(row);
        sh::base::FilesystemNodeType type = childnode->nodetype();
        bool result = true;
        result = (type == sh::base::FilesystemNodeType::Directory || type == sh::base::FilesystemNodeType::SpecialTreeOnlyDirectory);
        if (!result)
        {
            if (!childnode->linkDestinationNodes().isEmpty())
            {
                type = childnode->linkDestinationNodes().first()->nodetype();
                result = (type == sh::base::FilesystemNodeType::Directory || type == sh::base::FilesystemNodeType::SpecialTreeOnlyDirectory);
            }
        }
        return result && !childnode->eurl()->basename().startsWith(".");
    }
    else
        return true;
}

bool sh::base::FilesystemModelDirectoryTreeProxy::filterAcceptsColumn (int column, const QModelIndex&  ) const
{
    return (column == 0);
}

bool sh::base::FilesystemModelDirectoryTreeProxy::lessThan (const QModelIndex & left, const QModelIndex & right ) const
{
    if (!left.isValid()) return true;
    if (!right.isValid()) return false;
    std::shared_ptr<sh::base::FilesystemNode> nleft = sh::base::FilesystemModel::instance()->getNodeForIndex(left);
    std::shared_ptr<sh::base::FilesystemNode> nright = sh::base::FilesystemModel::instance()->getNodeForIndex(right);

    int typediff = (int)nright->nodetype() - (int)nleft->nodetype();
    if (typediff!=0) return (typediff<0);

    return QSortFilterProxyModel::lessThan(left, right);
}
