/*
Shallot is a Qt based file manager.
Copyright (C) 2014-2017 Josef Hahn

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef FILESYSTEMMODELDIRECTORYTREEPROXY_H
#define FILESYSTEMMODELDIRECTORYTREEPROXY_H

#include <QSortFilterProxyModel>


namespace sh {
    namespace base{

        /** \brief A filesystem proxy model for the directory tree.
         *
         * It has a special sorting and filtering behavior.
         *
         * Used internally, mostly for the user interface.
         */
        class FilesystemModelDirectoryTreeProxy : public QSortFilterProxyModel
        {
            Q_OBJECT
        public:
            /** \brief Constructed only indirectly.
             */
            explicit FilesystemModelDirectoryTreeProxy(QObject *parent = 0);

        protected:
            bool filterAcceptsRow (int row, const QModelIndex & parent) const;
            bool filterAcceptsColumn (int column, const QModelIndex & parent ) const;
            bool lessThan ( const QModelIndex & left, const QModelIndex & right ) const;

        };

    }
}

#endif // FILESYSTEMMODELDIRECTORYTREEPROXY_H
