/*
Shallot is a Qt based file manager.
Copyright (C) 2014-2017 Josef Hahn

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef VISIBLEVIEWS_H
#define VISIBLEVIEWS_H

#include <memory>
#include <QMap>
#include <QObject>


namespace sh{
    namespace base{class FilesystemNode;}

    namespace tools {

        /** \brief
         * Used for keeping track of which fileviews show which directories.
         *
         * Whenever the view goes to other directories, this manager gets
         * notified and redirects the notification to some other parts of the
         * program.
         */
        class VisibleViews
        {
        public:
            /** \brief
             * Returns the instance of this singleton.
             */
            static VisibleViews* instance();
            /** \brief
             * Only called by the Shallot infrastructure for initialization.
             */
            void _initialize();
            /** \brief
             * Only called by the Shallot infrastructure for shutdown.
             */
            void _shutdown();
            std::shared_ptr<QObject> viewEnteredDirectory(std::shared_ptr<sh::base::FilesystemNode> dir);
            void deleteLater();
        private:
            VisibleViews();
            QMap<std::shared_ptr<sh::base::FilesystemNode>, int> visibleDirs;
        };

    }
}

#endif // VISIBLEVIEWS_H
